// Module Name: grid.h
// Author:      Stephen Manley (smanley@nyx.net)
//
// Description:
// 
// This class implments a grid of tiles that the user can independantly
// select to be any color. This allows the user to define a colored 
// path of tiles which will later represent the maze.
// 
////////////////////////////////////////////////////////////////////////////

#ifndef MAZEGRID
#define MAZEGRID
#include "iostream.h"

#ifndef TILE
#include "square.h"
#endif

class MazeGrid
{
   public:

      // Constructors & Destructors
      MazeGrid(char* filename, int x, int y, int sizeX, int sizeY, int space);
      MazeGrid();
      ~MazeGrid();

      void init();  // Initializes the grid
      void draw();  // Draws the grid and member tiles
	  void save();  // Saves the grid to disk
	  void load();  // Attempts to load the grid from disk
	  void clear(); // Clears the grid with the background color

      // Checks to see if the grid contains a point 
	  int containsPoint(double worldX, double worldY);	

      void setActiveColor(double r, double g, double b);
      void setBackgroundColor(double r, double g, double b);
      void setGridColor(double r, double g, double b);

      void getActiveColor(double &r, double &g, double &b);
      void getBackgroundColor(double &r, double &g, double &b);
      
	  Tile* getTile(int tile);
	  Tile* getActiveTile();

   private:

      int xSize;
      int ySize;
      
      int xOrigin;
      int yOrigin;
      int gridSpacing;
      int tileSize;

      char* filename;

	  double rSelectColor, gSelectColor, bSelectColor;
	  double rBackgroundColor, gBackgroundColor, bBackgroundColor;
      double rGridColor, gGridColor, bGridColor;
      
	  Tile* activeTile;
	  Tile* gridTiles[400];	

	  double* gridColors; 
};
#endif
