// Module Name: menu.cpp
// Author:      Stephen Manley (smanley@nyx.net)
//
// Description:
// 
// This method implements a color menu for the mazemaker class. It
// allows the user to select a active color that can then be used
// to draw on the grid with.
// 
////////////////////////////////////////////////////////////////////////////

#ifndef COLORMENU
#include "menu.h"
#endif

#ifndef TILE
#include "square.h"
#endif

#include "GL/gl.h"

// Creates a menu at the specified X and Y coordinates
ColorMenu::ColorMenu(int x, int y)
{
   xCenter = x;
   yCenter = y;

   rActive = 0.0;
   bActive = 0.0;
   gActive = 0.0;

   color1 = new Tile(25, 21, 3., 1., 0., 0.);
   color1->setShaded(1);
   
   color2 = new Tile(25, 16, 3., 0., 1., 0.);
   color2->setShaded(1);

   color3 = new Tile(25, 11, 3., 0., 0., 1.);
   color3->setShaded(1);

   color4 = new Tile(25, 6, 3., 1., 1., 0.);
   color4->setShaded(1);
}

ColorMenu::ColorMenu()
{
}

ColorMenu::~ColorMenu()
{
}

void ColorMenu::draw()
{
	// Draw the 4 tiles
	color1->draw();
	color2->draw();
	color3->draw();
	color4->draw();
}

// Determines if the user clicked in the menu and if so, sets the
// active menu drawing color to the one chosen.
int ColorMenu::containsPoint(double worldX, double worldY)
{
   double r, g, b;

   // Check tile 1
   if (color1->containsPoint(worldX, worldY) == 0)
   {
       color1->getTileColor(r, g, b);

       color1->setShaded(0);
       color2->setShaded(1);
       color3->setShaded(1);
       color4->setShaded(1);
       
       this->setActiveColor(r, g, b);
     
       return 0;
   }
   
   // Check tile 2
   if (color2->containsPoint(worldX, worldY) == 0)
   {
       color2->getTileColor(r, g, b);

       color1->setShaded(1);
       color2->setShaded(0);
       color3->setShaded(1);
       color4->setShaded(1);

       this->setActiveColor(r, g, b);

       return 0;
   }

   // Check tile 3
   if (color3->containsPoint(worldX, worldY) == 0)
   { 
       color3->getTileColor(r, g, b);

       color1->setShaded(1);
       color2->setShaded(1);
       color3->setShaded(0);
       color4->setShaded(1);

       this->setActiveColor(r, g, b);

       return 0;
   }
   
   // Check tile 3
   if (color4->containsPoint(worldX, worldY) == 0)
   { 
       color4->getTileColor(r, g, b);

       color1->setShaded(1);
       color2->setShaded(1);
       color3->setShaded(1);
       color4->setShaded(0);

       this->setActiveColor(r, g, b);

       return 0;
   }

   return -1;
}

void ColorMenu::getActiveColor(double &r, double &g, double &b)
{
    r = rActive;
    b = bActive;
    g = gActive;
}

void ColorMenu::setActiveColor(double r, double g, double b)
{
    rActive = r;
    gActive = g;
    bActive = b;
}
