// Module Name: tile.cpp
// Author:      Stephen Manley (smanley@nyx.net)
//
// Description:
// 
// This class represents a rectangular, clickable area. It is used to
// define a 2D region of the screen with some properties such as color
// and location.
// 
////////////////////////////////////////////////////////////////////////////

#include "iostream.h"
#include "GL/gl.h"

#ifndef COLORMENU
#include "menu.h" // rgb struct
#endif

#ifndef TILE
#include "square.h"
#endif

// Default constuctor. Creates a tile object that is based at x,y 
// with the specified size and rgb color.
Tile::Tile(int x, int y, double size, double r, double g, double b)
{
	xOrigin = x;
	yOrigin = y;
	
	this->tilesize = size;

    rTile = r;
    gTile = g;
    bTile = b;

    shaded = 0;
}

Tile::Tile()
{
}

Tile::~Tile()
{
}

// Toggles the appearance of the tile (using transparency)
void Tile::setShaded(int value)
{
    shaded = value;
}

void Tile::setTileColor(double r, double g, double b)
{
	rTile = r;
	gTile = g;
	bTile = b;
}

void Tile::getTileColor(double &r, double &g, double &b)
{
	r = rTile;
	b = bTile;
	g = gTile;
}

// Determines if a point is contained within the bounds of the tile.
// This method will return 0 on success and -1 if a point is not found.
int Tile::containsPoint(double x, double y)
{
   // Check the world boundaries
   if ((x > xOrigin) && (x < xOrigin+tilesize) && (y < yOrigin) && (y > yOrigin-tilesize))
   {
       return 0;
   }

   return -1;
}

// Draws the tile on the screen. The active tile color is automatically
// activated.
void Tile::draw()
{
   if  (!shaded)
       glColor4f(rTile, gTile, bTile, 1.0);
   else
       glColor4f(rTile, gTile, bTile, 0.5);
       
   glBegin(GL_QUADS);

       glVertex2d(xOrigin,yOrigin);
       glVertex2d(xOrigin+tilesize, yOrigin);
       glVertex2d(xOrigin+tilesize, yOrigin-tilesize);
       glVertex2d(xOrigin, yOrigin-tilesize); 

   glEnd();

}

